package com.gxlu.ps.netcruise.md.nmsctrl;

import com.gxlu.ps.netcruise.md.GlobalInstance;
import com.gxlu.ps.netcruise.md.util.Alarm;
import com.gxlu.ps.netcruise.md.util.DateTool;
import com.gxlu.ps.netcruise.md.util.WinStyleLineReader;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.Socket;

/* loaded from: com_gxlu_ps_netcruise_md_nmsctrl.jar:com/gxlu/ps/netcruise/md/nmsctrl/AlarmReceiveThread.class */
public class AlarmReceiveThread extends Thread {
    private Socket receiveSock;
    private WinStyleLineReader alrmReceiver;
    private NMSCommunicator parent;
    private int alarmChannelStatus = 1;
    private boolean isShutdown = false;

    public AlarmReceiveThread() {
    }

    public AlarmReceiveThread(Socket sock) {
        this.receiveSock = sock;
    }

    public void setParent(NMSCommunicator aCommunicator) {
        this.parent = aCommunicator;
    }

    @Override // java.lang.Thread, java.lang.Runnable
    public void run() {
        String NMSIP = this.receiveSock.getInetAddress().getHostAddress();
        GlobalInstance.getInstance().getLogger().info("Alarm listening server got request from ".concat(String.valueOf(String.valueOf(NMSIP))));
        NMSCommunicatorMgr communicatorMgr = GlobalInstance.getInstance().getNMSCommunicatorMgr();
        NMSCommunicator comm = communicatorMgr.getCommunicatorByIP(NMSIP);
        if (comm == null) {
            GlobalInstance.getInstance().getLogger().warn("Alarm receive thread can not find communicator");
            return;
        }
        if (communicatorMgr.setAlarmThreadByIP(NMSIP, this) == 0) {
            setParent(comm);
        }
        try {
            this.alrmReceiver = new WinStyleLineReader(new BufferedReader(new InputStreamReader(this.receiveSock.getInputStream())));
            String now = DateTool.getNow();
            GlobalInstance.getInstance().getLogger().debug(String.valueOf(String.valueOf(this.parent.getSpecailty())).concat(" :Alarm channel created"));
            Alarm aItem = new Alarm();
            aItem.setContent(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(GlobalInstance.getInstance().getErrParser().getErrDescription(801)))).append("|").append(now).append("\r\n"))));
            GlobalInstance.getInstance().getAlarmPool().saveAlarm(aItem, 1);
            synchronized (this.parent.receiveStatusLock) {
                this.alarmChannelStatus = 2;
                this.parent.receiveStatusLock.notifyAll();
            }
            while (!this.isShutdown) {
                try {
                    try {
                        String alarmContent = this.alrmReceiver.readLine();
                        String now2 = DateTool.getNow();
                        if (alarmContent != null) {
                            GlobalInstance.getInstance().getLogger().info(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(" :Receive alarm =").append(alarmContent))));
                            String alarmContent2 = alarmContent.substring(0, alarmContent.length() - 2);
                            Alarm aItem2 = new Alarm();
                            aItem2.setContent(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append("|").append(alarmContent2).append("|").append(now2).append("\r\n"))));
                            GlobalInstance.getInstance().getAlarmPool().saveAlarm(aItem2, 1);
                            if (this.parent.getCommandChannelStatus() > 3) {
                                this.parent.setNMSSyncTime(DateTool.getTimebefore(this.parent.getTimeBetween()));
                            }
                        }
                    } catch (Throwable th) {
                        try {
                            this.alrmReceiver.close();
                            this.receiveSock.close();
                            GlobalInstance.getInstance().getLogger().debug(String.valueOf(String.valueOf(this.parent.getSpecailty())).concat("alarm socket closed "));
                        } catch (IOException var26) {
                            GlobalInstance.getInstance().getLogger().error(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(":Alarm channel close error= ").append(var26.getMessage()))));
                        }
                        this.alarmChannelStatus = 1;
                        GlobalInstance.getInstance().getLogger().info(String.valueOf(String.valueOf(this.parent.getSpecailty())).concat(":Alarm channel shutdowned "));
                        throw th;
                    }
                } catch (IOException var29) {
                    if (!this.isShutdown) {
                        GlobalInstance.getInstance().getLogger().error(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(":Alarm channel disconnected ").append(var29.getMessage()))));
                        this.alarmChannelStatus = 1;
                        String now3 = DateTool.getNow();
                        Alarm aItem3 = new Alarm();
                        aItem3.setContent(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(GlobalInstance.getInstance().getErrParser().getErrDescription(800)))).append("|").append(now3).append("\r\n"))));
                        GlobalInstance.getInstance().getAlarmPool().saveAlarm(aItem3, 1);
                    }
                    try {
                        this.alrmReceiver.close();
                        this.receiveSock.close();
                        GlobalInstance.getInstance().getLogger().debug(String.valueOf(String.valueOf(this.parent.getSpecailty())).concat("alarm socket closed "));
                    } catch (IOException var262) {
                        GlobalInstance.getInstance().getLogger().error(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(":Alarm channel close error= ").append(var262.getMessage()))));
                    }
                    this.alarmChannelStatus = 1;
                    GlobalInstance.getInstance().getLogger().info(String.valueOf(String.valueOf(this.parent.getSpecailty())).concat(":Alarm channel shutdowned "));
                    return;
                }
            }
            try {
                this.alrmReceiver.close();
                this.receiveSock.close();
                GlobalInstance.getInstance().getLogger().debug(String.valueOf(String.valueOf(this.parent.getSpecailty())).concat("alarm socket closed "));
            } catch (IOException var263) {
                GlobalInstance.getInstance().getLogger().error(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(":Alarm channel close error= ").append(var263.getMessage()))));
            }
            this.alarmChannelStatus = 1;
            GlobalInstance.getInstance().getLogger().info(String.valueOf(String.valueOf(this.parent.getSpecailty())).concat(":Alarm channel shutdowned "));
        } catch (IOException var28) {
            GlobalInstance.getInstance().getLogger().error("Alarm receiving reader can not created".concat(String.valueOf(String.valueOf(var28.getMessage()))));
            try {
                this.alrmReceiver.close();
            } catch (IOException var25) {
                GlobalInstance.getInstance().getLogger().error(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(":Alarm channel close error= ").append(var25.getMessage()))));
            }
        }
    }

    public void shutdownThread() {
        this.isShutdown = true;
    }

    public void shutdownByforce() {
        try {
            if (this.alrmReceiver != null) {
                this.alrmReceiver.close();
            }
            if (this.receiveSock != null) {
                this.receiveSock.close();
            }
        } catch (IOException var2) {
            GlobalInstance.getInstance().getLogger().error(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(":Alarm channel close error= ").append(var2.getMessage()))));
        }
        this.alarmChannelStatus = 1;
        GlobalInstance.getInstance().getLogger().info(String.valueOf(String.valueOf(this.parent.getSpecailty())).concat(":Alarm channel shutdowned "));
    }

    public int getAlarmChannelStatus() {
        return this.alarmChannelStatus;
    }
}
